@@ -1,3 +1,5 @@
+import pandas as pd
+
 table_style = [
     dict(selector="tr:hover",
          props=[("background", "#D6EEEE")]),
@@ -8,12 +10,12 @@ table_style = [
                                ("background", "#1D4477"),
                                ("font-size", "18px")
                                ]),
-    dict(selector="td", props=[("color", "#000000"),
-                               ("border", "1px solid #eee"),
-                               ("padding", "10px 20px"),
-                               ("border-collapse", "collapse"),
-                               ("font-size", "15px")
-                               ]),
+    dict(selector="td", props=[
+        ("border", "1px solid #eee"),
+        ("padding", "10px 20px"),
+        ("border-collapse", "collapse"),
+        ("font-size", "15px")
+    ]),
     dict(selector="table", props=[
         ("font-family", 'Helvetica'),
         ("margin", "25px auto"),
@@ -28,6 +30,19 @@ table_style = [
 ]
 
 
-def generate_table(df):
-    res = df.style.set_table_styles(table_style)
+def color_accounting(val):
+    """
+    Takes a scalar and returns a string with
+    the css property `'color: red'` for negative
+    strings, green otherwise.
+    """
+    color = 'red' if val < 0 else 'green'
+    return 'color: %s' % color
+
+
+def generate_table(df: pd.DataFrame, accounting_col_columns: list = None):
+    if accounting_col_columns:
+        res = (df.style.applymap(color_accounting, subset=accounting_col_columns).set_table_styles(table_style))
+    else:
+        res = df.style.set_table_styles(table_style)
     return res.to_html()
